/*
 * Update the database schema
 *
 * This script must be executed on all Sitecore databases.
 */
SET SERVEROUTPUT ON

DECLARE
  COLUMN_EXISTS EXCEPTION;
  PRAGMA EXCEPTION_INIT(COLUMN_EXISTS, -1430);
BEGIN 
   DBMS_OUTPUT.PUT_LINE('Adding Stamp column to EventQueue table...');
   EXECUTE IMMEDIATE 'ALTER TABLE "EventQueue" ADD ("Stamp" NUMBER(20,0) NOT NULL)';
   DBMS_OUTPUT.PUT_LINE('* DONE');
   
   DBMS_OUTPUT.PUT_LINE('Adding trigger for Stamp column to EventQueue table...');
   EXECUTE IMMEDIATE 'CREATE OR REPLACE TRIGGER "EVENTQUEUE_INSERT" 
   BEFORE
   INSERT ON "EventQueue" FOR EACH ROW begin
    if :new."Stamp" is null then
        select EVENTQUEUE_SEQ.nextval into :new."Stamp" from dual;
    end if;
   end;';
   DBMS_OUTPUT.PUT_LINE('* DONE');

   EXCEPTION
    WHEN COLUMN_EXISTS THEN
      DBMS_OUTPUT.PUT_LINE('COLUMN EXISTS');
   DBMS_OUTPUT.PUT_LINE('Correcting trigger for Stamp column to EventQueue table...');
   EXECUTE IMMEDIATE 'CREATE OR REPLACE TRIGGER "EVENTQUEUE_INSERT" 
   BEFORE
   INSERT ON "EventQueue" FOR EACH ROW begin
    if :new."Stamp" is null then
        select EVENTQUEUE_SEQ.nextval into :new."Stamp" from dual;
    end if;
   end;';
   DBMS_OUTPUT.PUT_LINE('* DONE');   
END;

/
QUIT