/*
 * Update the database schema
 *
 * This script must be executed on all Sitecore databases.
 */
SET SERVEROUTPUT ON

DECLARE
  INDEX_DOES_NOT_EXISTS EXCEPTION;
  PRAGMA EXCEPTION_INIT(INDEX_DOES_NOT_EXISTS, -1418);
  INDEX_EXISTS EXCEPTION;
  PRAGMA EXCEPTION_INIT(INDEX_EXISTS, -955);
  COLUMN_DOES_NOT_EXISTS EXCEPTION;
  PRAGMA EXCEPTION_INIT(COLUMN_DOES_NOT_EXISTS, -904);

BEGIN 
  DBMS_OUTPUT.PUT_LINE('Dropping index IX_Sequence_EventQueue on EventQueue table...');
  BEGIN
   EXECUTE IMMEDIATE 'DROP INDEX "IX_Sequence_EventQueue"';
   DBMS_OUTPUT.PUT_LINE('* DONE');
   EXCEPTION
     WHEN INDEX_DOES_NOT_EXISTS THEN
       DBMS_OUTPUT.PUT_LINE('INDEX DOES NOT EXISTS');
  END;
      
  DBMS_OUTPUT.PUT_LINE('Creating index IX_Stamp on EventQueue table...');
  BEGIN
   EXECUTE IMMEDIATE 'CREATE UNIQUE INDEX "IX_Stamp" ON "EventQueue" ("Stamp" ASC)';
   DBMS_OUTPUT.PUT_LINE('* DONE');
   EXCEPTION
    WHEN INDEX_EXISTS THEN
      DBMS_OUTPUT.PUT_LINE('INDEX ALREADY EXISTS');
    WHEN COLUMN_DOES_NOT_EXISTS THEN
      DBMS_OUTPUT.PUT_LINE('COLUMN Stamp DOES NOT EXISTS. PLEASE EXECUTE 6.4.1_BeforeInstall.oracle SCRIPT FIRST');
  END;
  
  DBMS_OUTPUT.PUT_LINE('Droping column Sequence on EventQueue table...');
  BEGIN
   EXECUTE IMMEDIATE 'ALTER TABLE "EventQueue" DROP COLUMN "Sequence"';
   DBMS_OUTPUT.PUT_LINE('* DONE');
   EXCEPTION
    WHEN COLUMN_DOES_NOT_EXISTS THEN
      DBMS_OUTPUT.PUT_LINE('COLUMN DOES NOT EXISTS');
  END;
END;

/
QUIT